%bcond_with     test

Summary:        Storage array management library
Name:           libstoragemgmt
Version:        1.9.8
Release:        5%{?dist}
License:        LGPLv2+
URL:            https://github.com/libstorage/libstoragemgmt
Source0:        https://github.com/libstorage/libstoragemgmt/releases/download/%{version}/%{name}-%{version}.tar.gz
Requires:       python3-%{name}
Provides:       %{name}-netapp-plugin <= 1.6.2-10
Provides:       %{name}-nstor-plugin <= 1.9.0-1

BuildRequires:  gcc gcc-c++ autoconf automake libtool
BuildRequires:  check-devel perl-interpreter glib2-devel systemd bash-completion libconfig-devel systemd-devel procps sqlite-devel python3-six python3-devel

%{?systemd_requires}
BuildRequires:  systemd systemd-devel

BuildRequires:  chrpath
BuildRequires:  valgrind

%description
The libStorageMgmt library will provide a vendor agnostic open source storage
application programming interface (API) that will allow management of storage
arrays.  The library includes a command line interface for interactive use and
scripting (command lsmcli).  The library also has a daemon that is used for
executing plug-ins in a separate process (lsmd).

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        -n python3-%{name}
Summary:        Python 3 client libraries and plug-in support for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       python3-six
Provides:       python2-%{name}-clibs <= 1.9.0-1
Provides:       python3-%{name}-clibs <= 1.9.0-1

%description    -n python3-%{name}
This contains python 3 client libraries as well as python framework
support and open source plug-ins written in python 3.

%package        smis-plugin
Summary:        Files for SMI-S generic array support for %{name}
BuildRequires:  python3-pywbem
BuildRequires:  make
Requires:       python3-pywbem
BuildArch:      noarch
Provides:       %{name}-ibm-v7k-plugin <= 2:1.9.3-4
Requires:       python3-%{name} = %{version}
Requires(post): python3-%{name} = %{version}
Requires(postun): python3-%{name} = %{version}


%description    smis-plugin
The %{name}-smis-plugin package contains plug-in for generic SMI-S array
support.

%package        targetd-plugin
Summary:        Files for targetd array support for %{name}
Requires:       python3-%{name} = %{version}
Requires(post): python3-%{name} = %{version}
Requires(postun): python3-%{name} = %{version}
BuildArch:      noarch

%description    targetd-plugin
The %{name}-targetd-plugin package contains plug-in for targetd array
support.

%package        udev
Summary:        Udev files for %{name}

%description    udev
The %{name}-udev package contains udev rules and helper utilities for
uevents generated by the kernel.

%package        megaraid-plugin
Summary:        Files for LSI MegaRAID support for %{name}
Requires:       python3-%{name} = %{version}
Requires(post): python3-%{name} = %{version}
Requires(postun): python3-%{name} = %{version}
BuildArch:      noarch

%description    megaraid-plugin
The %{name}-megaraid-plugin package contains the plugin for LSI
MegaRAID storage management via storcli.

%package        hpsa-plugin
Summary:        Files for HP SmartArray support for %{name}
Requires:       python3-%{name} = %{version}
Requires(post): python3-%{name} = %{version}
Requires(postun): python3-%{name} = %{version}
BuildArch:      noarch

%description    hpsa-plugin
The %{name}-hpsa-plugin package contains the plugin for HP
SmartArray storage management via hpssacli.

%package        arcconf-plugin
Summary:        Files for Microsemi Adaptec and Smart Family support for %{name}
Requires:       python3-%{name} = %{version}
Requires(post): python3-%{name} = %{version}
Requires(postun): python3-%{name} = %{version}
BuildArch:      noarch

%description    arcconf-plugin
The %{name}-arcconf-plugin package contains the plugin for Microsemi
Adaptec RAID and Smart Family Controller storage management.

%package        nfs-plugin
Summary:        Files for NFS local filesystem support for %{name}
Requires:       python3-%{name} = %{version}
Requires:       %{name} = %{version}-%{release}
Requires:       nfs-utils
Requires(post): python3-%{name} = %{version}
Requires(postun): python3-%{name} = %{version}

%description    nfs-plugin
The nfs-plugin package contains plug-in for local NFS exports support.

%package        local-plugin
Summary:        Files for local pseudo plugin of %{name}
Requires:       python3-%{name} = %{version}
Requires:       %{name}-arcconf-plugin = %{version}-%{release}
Requires:       %{name}-hpsa-plugin = %{version}-%{release}
Requires(post): python3-%{name} = %{version}
Requires(postun): python3-%{name} = %{version}
BuildArch:      noarch

%description    local-plugin
The %{name}-local-plugin is a plugin that provides auto
plugin selection for locally managed storage.



%prep
%autosetup -p1



%build
./autogen.sh

%configure --with-python3 --disable-static
%make_build



%install
rm -rf %{buildroot}

%make_install

find %{buildroot} -name '*.la' -exec rm -f {} ';'

mkdir -p %{buildroot}/%{_udevrulesdir}
install -m 644 tools/udev/90-scsi-ua.rules \
    %{buildroot}/%{_udevrulesdir}/90-scsi-ua.rules
install -m 755 tools/udev/scan-scsi-target \
    %{buildroot}/%{_udevrulesdir}/../scan-scsi-target



%if 0%{with test}
%check
if ! make check
then
  cat test-suite.log || true
  exit 1
fi

%endif



%pre

echo 'u libstoragemgmt - "daemon account for libstoragemgmt"' | \
            systemd-sysusers --replace=/usr/lib/sysusers.d/libstoragemgmt.conf -

%post
/sbin/ldconfig
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
/sbin/ldconfig
%systemd_postun %{name}.service

%post smis-plugin
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%postun smis-plugin
if [ $1 -eq 0 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%post targetd-plugin
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%postun targetd-plugin
if [ $1 -eq 0 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%post megaraid-plugin
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi
%postun megaraid-plugin
if [ $1 -eq 0 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%post hpsa-plugin
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi
%postun hpsa-plugin
if [ $1 -eq 0 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%post arcconf-plugin
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi
%postun arcconf-plugin
if [ $1 -eq 0 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%post nfs-plugin
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi
%postun nfs-plugin
if [ $1 -eq 0 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%post local-plugin
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi
%postun local-plugin
if [ $1 -eq 0 ]; then
    /usr/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi



%files
%license COPYING.LIB
%doc README NEWS
%{_mandir}/man1/lsmcli.1*
%{_mandir}/man1/lsmd.1*
%{_mandir}/man5/lsmd.conf.5*
%{_libdir}/*.so.*
%{_bindir}/lsmcli
%{_datadir}/bash-completion/completions/lsmcli
%{_bindir}/lsmd
%{_bindir}/simc_lsmplugin
%dir %{_sysconfdir}/lsm
%dir %{_sysconfdir}/lsm/pluginconf.d
%config(noreplace) %{_sysconfdir}/lsm/lsmd.conf
%{_mandir}/man1/simc_lsmplugin.1*
%{_unitdir}/%{name}.service
%ghost %dir %attr(0775, root, libstoragemgmt) /run/lsm/
%ghost %dir %attr(0775, root, libstoragemgmt) /run/lsm/ipc
%attr(0644, root, root) %{_tmpfilesdir}/%{name}.conf

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/lsm_*
%{_mandir}/man3/libstoragemgmt*

%files -n python3-%{name}
%dir %{python3_sitearch}/lsm
%{python3_sitearch}/lsm/__init__.*
%{python3_sitearch}/lsm/_client.*
%{python3_sitearch}/lsm/_common.*
%{python3_sitearch}/lsm/_local_disk.*
%{python3_sitearch}/lsm/_data.*
%{python3_sitearch}/lsm/_iplugin.*
%{python3_sitearch}/lsm/_pluginrunner.*
%{python3_sitearch}/lsm/_transport.*
%{python3_sitearch}/lsm/__pycache__/
%{python3_sitearch}/lsm/version.*
%dir %{python3_sitearch}/lsm/lsmcli
%{python3_sitearch}/lsm/lsmcli/__init__.*
%{python3_sitearch}/lsm/lsmcli/__pycache__/
%{python3_sitearch}/lsm/lsmcli/data_display.*
%{python3_sitearch}/lsm/lsmcli/cmdline.*
%{python3_sitearch}/lsm/_clib.*

%dir %{python3_sitearch}/sim_plugin
%{python3_sitearch}/sim_plugin/__pycache__/
%{python3_sitearch}/sim_plugin/__init__.*
%{python3_sitearch}/sim_plugin/simulator.*
%{python3_sitearch}/sim_plugin/simarray.*

%{_bindir}/sim_lsmplugin
%dir %{_libexecdir}/lsm.d
%{_libexecdir}/lsm.d/find_unused_lun.py*
%{_libexecdir}/lsm.d/local_check.py*
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/sim.conf
%{_mandir}/man1/sim_lsmplugin.1*

%files smis-plugin
%dir %{python3_sitelib}/smispy_plugin
%dir %{python3_sitelib}/smispy_plugin/__pycache__
%{python3_sitelib}/smispy_plugin/__pycache__/*
%{python3_sitelib}/smispy_plugin/__init__.*
%{python3_sitelib}/smispy_plugin/smis.*
%{python3_sitelib}/smispy_plugin/dmtf.*
%{python3_sitelib}/smispy_plugin/utils.*
%{python3_sitelib}/smispy_plugin/smis_common.*
%{python3_sitelib}/smispy_plugin/smis_cap.*
%{python3_sitelib}/smispy_plugin/smis_sys.*
%{python3_sitelib}/smispy_plugin/smis_pool.*
%{python3_sitelib}/smispy_plugin/smis_disk.*
%{python3_sitelib}/smispy_plugin/smis_vol.*
%{python3_sitelib}/smispy_plugin/smis_ag.*
%{_bindir}/smispy_lsmplugin
%{_mandir}/man1/smispy_lsmplugin.1*

%files targetd-plugin
%dir %{python3_sitelib}/targetd_plugin
%dir %{python3_sitelib}/targetd_plugin/__pycache__
%{python3_sitelib}/targetd_plugin/__pycache__/*
%{python3_sitelib}/targetd_plugin/__init__.*
%{python3_sitelib}/targetd_plugin/targetd.*
%{_bindir}/targetd_lsmplugin
%{_mandir}/man1/targetd_lsmplugin.1*

%files udev
%{_udevrulesdir}/../scan-scsi-target
%{_udevrulesdir}/90-scsi-ua.rules

%files megaraid-plugin
%dir %{python3_sitelib}/megaraid_plugin
%dir %{python3_sitelib}/megaraid_plugin/__pycache__
%{python3_sitelib}/megaraid_plugin/__pycache__/*
%{python3_sitelib}/megaraid_plugin/__init__.*
%{python3_sitelib}/megaraid_plugin/megaraid.*
%{python3_sitelib}/megaraid_plugin/utils.*
%{_bindir}/megaraid_lsmplugin
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/megaraid.conf
%{_mandir}/man1/megaraid_lsmplugin.1*

%files hpsa-plugin
%dir %{python3_sitelib}/hpsa_plugin
%dir %{python3_sitelib}/hpsa_plugin/__pycache__
%{python3_sitelib}/hpsa_plugin/__pycache__/*
%{python3_sitelib}/hpsa_plugin/__init__.*
%{python3_sitelib}/hpsa_plugin/hpsa.*
%{python3_sitelib}/hpsa_plugin/utils.*
%{_bindir}/hpsa_lsmplugin
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/hpsa.conf
%{_mandir}/man1/hpsa_lsmplugin.1*

%files nfs-plugin
%dir %{python3_sitearch}/nfs_plugin
%dir %{python3_sitearch}/nfs_plugin/__pycache__
%{python3_sitearch}/nfs_plugin/__pycache__/*
%{python3_sitearch}/nfs_plugin/__init__.*
%{python3_sitearch}/nfs_plugin/nfs.*
%{python3_sitearch}/nfs_plugin/nfs_clib.*
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/nfs.conf
%{_bindir}/nfs_lsmplugin
%{_mandir}/man1/nfs_lsmplugin.1*

%files arcconf-plugin
%dir %{python3_sitelib}/arcconf_plugin
%dir %{python3_sitelib}/arcconf_plugin/__pycache__
%{python3_sitelib}/arcconf_plugin/__pycache__/*
%{python3_sitelib}/arcconf_plugin/__init__.*
%{python3_sitelib}/arcconf_plugin/arcconf.*
%{python3_sitelib}/arcconf_plugin/utils.*
%{_bindir}/arcconf_lsmplugin
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/arcconf.conf
%{_mandir}/man1/arcconf_lsmplugin.1*

%files local-plugin
%dir %{python3_sitelib}/local_plugin
%dir %{python3_sitelib}/local_plugin/__pycache__
%{python3_sitelib}/local_plugin/__pycache__/*
%{python3_sitelib}/local_plugin/__init__.*
%{python3_sitelib}/local_plugin/local.*
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/local.conf
%{_bindir}/local_lsmplugin
%{_mandir}/man1/local_lsmplugin.1*



%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.8-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.8-4
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.8-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.8-2
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Jul 14 2023 Xiaojie Chen <jackxjchen@tencent.com> - 1.9.8-1
- Upgrade to upstream version 1.9.8

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.6-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.6-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Nov 16 2022 Zhao Zhen <jeremiazhao@tencent.com> - 1.9.6-1
- initial
